# Dead salmon brain

Python API for analysis A/B experiments

## Getting Started

### Build from source

```
1) Clone git repository
2) ./gradlew build
3) pip install python/
4) Add computing/build/libs/computing-*.*.*.jar to Spark jars/ folder
```

### Installation for python
```
1) pip install dead-salmon-brain
2) go to spark jars folder
3) wget https://maven.pkg.github.com/Salmon-Brain/dead-salmon-brain/ai.salmon.computiing/{VERSION}/computing-{VERSION}.jar
```

### Installation for jvm
```
add github repository and declare dependency
```

### Example

```
You can find in  python/examples
```
